package go_swagger

import (
	"path/filepath"

	"github.com/juju/errors"

	"git.home.m-and-m.ovh/mderasse/gouick/helpers"
	"git.home.m-and-m.ovh/mderasse/gouick/models"

	log "github.com/sirupsen/logrus"
)

type apiYamlTemplate struct {
	ProjectDescription string
	ProjectName        string
	ProjectContact     apiYamlContact
}

type apiYamlContact struct {
	Email string
	Name  string
	URL   string
}

// generateAPIYamls will generate a readme based on the given config.
// Launched only at project init.
func (a APIType) generateAPIYamls(path string, config *models.Config) error {
	log.Debugf("Starting %s - %s", a.GetName(), helpers.GetCurrentFuncName())

	type templateFileStruct struct {
		savePath     string
		templatePath string
	}

	templateFileList := []templateFileStruct{
		{
			savePath:     filepath.Join(path, "api.yaml"),
			templatePath: filepath.Join(templateDirectory, "api.yaml.tmpl"),
		},
		{
			savePath:     filepath.Join(path, "api/001-general.yaml"),
			templatePath: filepath.Join(templateDirectory, "api/001-general.yaml.tmpl"),
		},
		{
			savePath:     filepath.Join(path, "api/001-monitoring.yaml"),
			templatePath: filepath.Join(templateDirectory, "api/002-monitoring.yaml.tmpl"),
		},
	}

	data := apiYamlTemplate{
		ProjectDescription: config.ProjectDescription,
		ProjectName:        config.ProjectName,
		ProjectContact: apiYamlContact{
			Email: config.ProjectContact.Email,
			Name:  config.ProjectContact.Name,
			URL:   config.ProjectContact.URL,
		},
	}

	for _, templateFile := range templateFileList {

		err := helpers.WriteTemplate(templateFile.templatePath, templateFile.savePath, data)
		if err != nil {
			return errors.Trace(err)
		}
	}

	return nil
}
